@@ -6,6 +6,7 @@ import traceback
 import yaml
 import os
 import sys
+import codecs
 
 from psychopy.localization import _translate
 
@@ -26,7 +27,8 @@ alertLog : List
 
 _activeAlertHandlers = []
 
-class AlertCatalog(object):
+
+class AlertCatalog:
     """A class for loading alerts from the alerts catalogue yaml file"""
     def __init__(self):
         self.alert = self.load()
@@ -52,7 +54,7 @@ class AlertCatalog(object):
         for filePath in self.alertFiles:
             # '{}'.format(filePath) instead of simple open(filePath,'r')
             # is needed for Py2 support only
-            with open('{}'.format(filePath), 'r') as ymlFile:
+            with codecs.open('{}'.format(filePath), 'r', 'utf-8') as ymlFile:
                 entry = yaml.load(ymlFile, Loader=yaml.SafeLoader)
                 if entry is None:
                     continue  # this might be a stub for future entry
@@ -65,7 +67,7 @@ class AlertCatalog(object):
         return alertDict
 
 
-class AlertEntry(object):
+class AlertEntry:
     """An Alerts data class holding alert data as attributes
 
     Attributes
