@@ -2,16 +2,15 @@
 # -*- coding: utf-8 -*-
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2022 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
-from __future__ import absolute_import, division, print_function
-
-from builtins import object
 import sys
 import re
 import glob
+import time
 import zipfile
+import platform
 import os
 from pkg_resources import parse_version
 import wx
@@ -26,14 +25,10 @@ from .. import dialogs
 from psychopy.localization import _translate
 from psychopy import logging
 from psychopy import web
-from psychopy import constants
-if constants.PY3:
-    import io
-else:
-    import StringIO as io
+import io
 urllib = web.urllib
 
-versionURL = "http://www.psychopy.org/version.txt"
+versionURL = "https://www.psychopy.org/version.txt"
 
 """The Updater class checks for updates and suggests that an update is carried
 out if a new version is found. The actual updating is handled by
@@ -55,8 +50,7 @@ def getLatestVersionInfo(app=None):
     for line in page.readlines():
         # in some odd circumstances (wifi hotspots) you can fetch a
         # page that is not the correct URL but a redirect
-        if constants.PY3:
-            line = line.decode()  # convert from a byte to a str
+        line = line.decode()  # convert from a byte to a str
         if line.find(':') == -1:
             return -1
             # this will succeed if every line has a key
@@ -67,7 +61,7 @@ def getLatestVersionInfo(app=None):
     return latest
 
 
-class Updater(object):
+class Updater():
 
     def __init__(self, app=None, runningVersion=None):
         """The updater will check for updates and download/install as needed.
@@ -313,9 +307,14 @@ class InstallUpdateDialog(wx.Dialog):
         self.cancelBtn = wx.Button(self, -1, _translate('Close'))
         self.Bind(wx.EVT_BUTTON, self.onCancel, self.cancelBtn)
         btnSizer = wx.BoxSizer(wx.HORIZONTAL)
-        btnSizer.Add(self.installBtn)
-        btnSizer.Add(self.cancelBtn, flag= wx.LEFT, border=5)
-        mainSizer.Add(btnSizer, flag= wx.ALL, border=5)
+        btnSizer.AddStretchSpacer()
+        if sys.platform == "win32":
+            btns = [self.installBtn, self.cancelBtn]
+        else:
+            btns = [self.cancelBtn, self.installBtn]
+        btnSizer.Add(btns[0], 0, flag=wx.LEFT, border=5)
+        btnSizer.Add(btns[1], 0, flag=wx.LEFT, border=5)
+        mainSizer.Add(btnSizer, flag=wx.ALL | wx.EXPAND, border=15)
 
         self.SetSizerAndFit(mainSizer)
         self.SetAutoLayout(True)
@@ -329,11 +328,14 @@ class InstallUpdateDialog(wx.Dialog):
         """Check the current version and most recent version and update ctrls
         """
         if self.latest == -1:
+            # Set message and display, and return early if version could not be found
             msg = _translate(
                 "You are running PsychoPy v%s.\n ") % self.runningVersion
             msg += _translate("PsychoPy could not connect to the \n internet"
                               " to check for more recent versions.\n")
             msg += _translate("Check proxy settings in preferences.")
+            self.statusMessage.SetLabel(msg)
+            return
         elif (parse_version(self.latest['version'])
                   < parse_version(self.runningVersion)):
             msg = _translate(
@@ -442,15 +444,12 @@ class InstallUpdateDialog(wx.Dialog):
         otherwise try and retrieve a version number from zip file name
         """
         info = ""  # return this at the end
-        if constants.PY3:
-            zfileIsName = type(zfile) == str
-        else:
-            zfileIsName = type(zfile) in (str, unicode)
+        zfileIsName = type(zfile) == str
         if os.path.isfile(zfile) and zfileIsName:
             # zfile is filename not an actual file
             if v is None:  # try and deduce it
                 zFilename = os.path.split(zfile)[-1]
-                searchName = re.search('[0-9]*\.[0-9]*\.[0-9]*.', zFilename)
+                searchName = re.search(r'[0-9]*\.[0-9]*\.[0-9]*.', zFilename)
                 if searchName != None:
                     v = searchName.group(0)[:-1]
                 else:
@@ -629,7 +628,7 @@ def sendUsageStats():
         systemInfo = "win32_v" + platform.version()
     else:
         systemInfo = platform.system() + platform.release()
-    u = "http://www.psychopy.org/usage.php?date=%s&sys=%s&version=%s&misc=%s"
+    u = "https://www.psychopy.org/usage.php?date=%s&sys=%s&version=%s&misc=%s"
     URL = u % (dateNow, systemInfo, v, miscInfo)
     try:
         req = urllib.request.Request(URL)
