@@ -1,10 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function
-
 import json
-from builtins import str
+import sys
 import wx
 import wx.propgrid as pg
 import wx.py
@@ -48,6 +45,8 @@ _localized = {
     'shutdownKeyModifiers': _translate("shutdown key modifier keys"),
     'gammaErrorPolicy': _translate("gammaErrorPolicy"),
     'startUpPlugins': _translate("start up plugins"),
+    'appKeyGoogleCloud':_translate('appKeyGoogleCloud'),
+    'transcrKeyAzure':_translate('transcrKeyAzure'),
     # pref labels in App section
     'showStartupTips': _translate("show start-up tips"),
     'defaultView': _translate("default view"),
@@ -62,12 +61,14 @@ _localized = {
     'codeComponentLanguage': _translate('Code component language'),
     'unclutteredNamespace': _translate('uncluttered namespace'),
     'componentsFolders': _translate('components folders'),
+    'componentFilter':_translate('componentFilter'),
     'hiddenComponents': _translate('hidden components'),
     'unpackedDemosDir': _translate('unpacked demos dir'),
     'savedDataFolder': _translate('saved data folder'),
-    'topFlow': _translate('Flow at top'),
+    'builderLayout': _translate('Builder layout'),
     'alwaysShowReadme': _translate('always show readme'),
     'maxFavorites': _translate('max favorites'),
+    'confirmRoutineClose': _translate('confirmRoutineClose'),
     # pref labels in Coder section
     'readonly': _translate('read-only'),
     'outputFont': _translate('output font'),
@@ -141,6 +142,7 @@ _localized = {
     'audioDevice': _translate("audio device"),
     'parallelPorts': _translate("parallel ports"),
     'qmixConfiguration': _translate("Qmix configuration"),
+    'highDPI': _translate('Try to support display high DPI'),
     # pref labels in Connections section
     'proxy': _translate('proxy'),
     'autoProxy': _translate('auto-proxy'),
@@ -150,6 +152,8 @@ _localized = {
     # pref wxChoice lists:
     'all': _translate('Builder, Coder and Runner'),
     'keep': _translate('same as in the file'),  # line endings
+    'abort': _translate('abort'), # gammaErrorPolicy
+    'warn': _translate('warn'), # gammaErrorPolicy
     # not translated:
     'pix': 'pix',
     'deg': 'deg',
@@ -322,8 +326,9 @@ class PrefPropGrid(wx.Panel):
         if section not in self.sections.keys():
             self.sections[section] = []
 
-        self.sections[section].update(
-            {name: wx.propgrid.FileProperty(label, name, value)})
+        prop = wx.propgrid.FileProperty(label, name, value)
+        self.sections[section].update({name: prop})
+        prop.SetAttribute(wx.propgrid.PG_FILE_SHOW_FULL_PATH, True)
 
         self.helpText[name] = helpText
 
@@ -490,19 +495,30 @@ class PreferencesDlg(wx.Dialog):
         sbPrefs.Add(self.stlMain, 0, wx.EXPAND | wx.ALL, 5)
 
         # dialog controls, have builtin localization
-        sdbControls = wx.StdDialogButtonSizer()
+        sdbControls = wx.BoxSizer(wx.HORIZONTAL)
         self.sdbControlsHelp = wx.Button(self.pnlMain, wx.ID_HELP)
-        sdbControls.AddButton(self.sdbControlsHelp)
+        sdbControls.Add(self.sdbControlsHelp, 0,
+                        wx.LEFT | wx.ALL | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+        sdbControls.AddStretchSpacer()
+        # Add Okay and Cancel buttons
         self.sdbControlsApply = wx.Button(self.pnlMain, wx.ID_APPLY)
-        sdbControls.AddButton(self.sdbControlsApply)
         self.sdbControlsOK = wx.Button(self.pnlMain, wx.ID_OK)
-        sdbControls.AddButton(self.sdbControlsOK)
         self.sdbControlsCancel = wx.Button(self.pnlMain, wx.ID_CANCEL)
-        sdbControls.AddButton(self.sdbControlsCancel)
-
-        sdbControls.Realize()
-
-        sbPrefs.Add(sdbControls, 0, wx.ALL | wx.ALIGN_RIGHT, 0)
+        if sys.platform == "win32":
+            btns = [self.sdbControlsOK, self.sdbControlsApply, self.sdbControlsCancel]
+        else:
+            btns = [self.sdbControlsCancel, self.sdbControlsApply, self.sdbControlsOK]
+        sdbControls.Add(btns[0], 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+        sdbControls.Add(btns[1], 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+        sdbControls.Add(btns[2], 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+        sbPrefs.Add(sdbControls, flag=wx.ALL | wx.EXPAND, border=3)
 
         self.pnlMain.SetSizer(sbPrefs)
         self.pnlMain.Layout()
@@ -605,11 +621,12 @@ class PreferencesDlg(wx.Dialog):
                         default = self.fontList.index(thisPref)
                     except ValueError:
                         default = 0
+                    labels = [_translate(font) for font in self.fontList]
                     self.proPrefs.addEnumItem(
                             sectionName,
                             pLabel,
                             prefName,
-                            labels=self.fontList,
+                            labels=labels,
                             values=[i for i in range(len(self.fontList))],
                             value=default, helpText=helpText)
                 elif prefName in ('theme',):
@@ -634,7 +651,7 @@ class PreferencesDlg(wx.Dialog):
                         # set default locale ''
                         default = locales.index('')
                     # '' must be appended after other labels are translated
-                    labels = ['system locale'] + [_localized[i] 
+                    labels = [_translate('system locale')] + [_localized[i] 
                                      for i in self.app.localization.available]
                     self.proPrefs.addEnumItem(
                             sectionName,
@@ -649,7 +666,7 @@ class PreferencesDlg(wx.Dialog):
                         sectionName, pLabel, prefName, thisPref,
                         helpText=helpText)
                 # single file
-                elif prefName in ('flac',):
+                elif prefName in ('flac', 'appKeyGoogleCloud',):
                     self.proPrefs.addFileItem(
                         sectionName, pLabel, prefName, thisPref,
                         helpText=helpText)
@@ -723,6 +740,12 @@ class PreferencesDlg(wx.Dialog):
                             labels=labels,
                             values=[i for i in range(len(labels))],
                             value=default, helpText=helpText)
+                    if prefName == 'builderLayout':
+                        item = self.proPrefs.sections[sectionName][prefName]
+                        for i in range(len(item.GetChoices())):
+                            choice = item.GetChoices()[i]
+                            icon = self.app.iconCache.getBitmap(choice.Text)
+                            choice.SetBitmap(icon)
                 # # lists are given a property that can edit and reorder items
                 elif thisSpec.startswith('list'):  # list
                     self.proPrefs.addStringArrayItem(
@@ -745,7 +768,7 @@ class PreferencesDlg(wx.Dialog):
             return
 
         if platform.system() == 'Darwin':
-            re_cmd2ctrl = re.compile('^Cmd\+', re.I)
+            re_cmd2ctrl = re.compile(r'^Cmd\+', re.I)
 
         for sectionName in self.prefsSpec:
             for prefName in self.prefsSpec[sectionName]:
@@ -833,22 +856,31 @@ class PreferencesDlg(wx.Dialog):
         # > sure, why not? - mdc
         self.populatePrefs()
 
+        # Update Builder window if needed
+        if self.app.builder:
+            self.app.builder.updateAllViews()
+
         # after validation, update the UI
         self.app.theme = self.app.theme
-        self.updateCoderUI()
+        self.updateFramesUI()
 
-    def updateCoderUI(self):
+    def updateFramesUI(self):
         """Update the Coder UI (eg. fonts, themes, etc.) from prefs."""
-        # start applying prefs to take effect
-        coder = self.app.coder
-        if coder is not None:
-            # apply settings over document pages
-            for ii in range(coder.notebook.GetPageCount()):
-                doc = coder.notebook.GetPage(ii)
-                doc.theme = prefs.app['theme']
-            for ii in range(coder.shelf.GetPageCount()):
-                doc = coder.shelf.GetPage(ii)
-                doc.theme = prefs.app['theme']
+        for frame in self.app.getAllFrames():
+            if frame.frameType == 'builder':
+                frame.layoutPanes()
+            elif frame.frameType == 'coder':
+                # apply settings over document pages
+                for ii in range(frame.notebook.GetPageCount()):
+                    doc = frame.notebook.GetPage(ii)
+                    doc.theme = prefs.app['theme']
+                for ii in range(frame.shelf.GetPageCount()):
+                    doc = frame.shelf.GetPage(ii)
+                    doc.theme = prefs.app['theme']
+
+                # apply console font, not handled by theme system ATM
+                if hasattr(frame, 'shell'):
+                    frame.shell.setFonts()
 
     def OnApplyClicked(self, event):
         """Apply button clicked, this makes changes to the UI without leaving
