@@ -18,13 +18,10 @@ The following variables control what video is played during the test as well as
 other configuration settings:
 """
 
-from __future__ import division
-from __future__ import print_function
-
 #   Test Config.
 
 # Relative path (from this scripts folder) for the video clip to be played .
-video_name = r'./jwpIntro.mov'
+video_name = r'./jwpIntro.mp4'
 
 # If False, no audio tracks will be played.
 INCLUDE_AUDIO_TRACK = True
@@ -74,7 +71,7 @@ Example Results File Output
 
  ** Video Info **
 Video File:
-    Name: 	./jwpIntro.mov
+    Name: 	./jwpIntro.mp4
     Frame Count: 	145.0
     Width: 	320.0
     Height: 	240.0
@@ -177,7 +174,7 @@ frame_num	frame_flip_time	playback_duration	frame_num_dx	dropped_count
 """
 
 
-from psychopy import visual, core, event
+from psychopy import visual, core, event, constants
 
 getTime = core.getTime
 import time, os, numpy as np
@@ -313,7 +310,7 @@ def getSysInfo(win):
                 vattrs = ['name', 'exe', 'ppid', 'num_threads', 'memory_percent', 'cpu_percent', 'cpu_affinity', 'nice',
                           'num_ctx_switches']
                 procinfo = proc.as_dict(attrs=vattrs, ad_value=u"Access Denied")
-                if procinfo['exe'] is not u"Access Denied" and (SAVE_PER_PROCESS_DATA is True or SAVE_PER_PROCESS_DATA == procinfo['name']):
+                if procinfo['exe'] != "Access Denied" and (SAVE_PER_PROCESS_DATA is True or SAVE_PER_PROCESS_DATA == procinfo['name']):
                     sys_info['Processes'][pkey] = procinfo
         except ImportError:
             sys_info['Processes']['Failed'] = 'psutil 2.x + is required.'
@@ -336,7 +333,7 @@ def formattedDictStr(d, indent=1, rstr=''):
     return rstr
 
 def bytes2human(n):
-    # http://code.activestate.com/recipes/578019
+    # https://code.activestate.com/recipes/578019/
     # >>  > bytes2human(10000)
     # '9.8K'
     # >>  > bytes2human(100001221)
@@ -398,12 +395,11 @@ def createResultsFile():
             f.write("Video File:\n")
             f.write("\tName:\t{0}\n".format(video_name))
             f.write("\tFrame Count:\t{0}\n".format(mov._total_frame_count))
-            mov_duration = mov._total_frame_count/mov._video_stream.get(cv2.cv.CV_CAP_PROP_FPS)
+            mov_duration = mov._total_frame_count/mov._video_stream.get(cv2.CAP_PROP_FPS)
             f.write("\tVideo Duration:\t{0}\n".format(mov_duration))
             f.write("\tWidth:\t{0}\n".format(mov._video_width))
             f.write("\tHeight:\t{0}\n".format(mov._video_height))
-            f.write("\tFPS (Format, Requested):\t{0}\n".format(
-                (mov._video_stream.get(cv2.cv.CV_CAP_PROP_FPS), mov._requested_fps)))
+            f.write("\tFPS:\t{0}\n".format(mov.getFPS()))
             f.write("\tPlay Audio Track:\t{0}\n".format(not mov._no_audio))
 
             f.write("Video Display:\n")
@@ -480,7 +476,7 @@ if __name__ == '__main__':
     display_frame_num = mov.play()
     draw_dur = getTime() - dt1
 
-    while mov.status != visual.FINISHED:
+    while mov.status != constants.FINISHED:
         # Only flip when a new frame should be displayed. Can significantly reduce
         # CPU usage. This only makes sense if the movie is the only /dynamic/ stim
         # displayed.
@@ -504,7 +500,7 @@ if __name__ == '__main__':
         # Check for action keys.....
         for key in event.getKeys():
             if key in ['escape', 'q']:
-                mov.status = visual.FINISHED
+                mov.status = constants.FINISHED
                 break
 
     createResultsFile()
@@ -516,7 +512,7 @@ if __name__ == '__main__':
 # Movie2 logic not currently used / tested by this script
 
 #        elif key in ['s', ]:
-#            if mov.status in [visual.PLAYING, visual.PAUSED]:
+#            if mov.status in [constants.PLAYING, constants.PAUSED]:
 #                # To stop the movie being played.....,
 #                mov.stop()
 #                # Clear screen of last displayed frame.
@@ -531,9 +527,9 @@ if __name__ == '__main__':
 #                display_frame_num = mov.play()
 #        elif key in ['p', ]:
 #            # To pause the movie while it is playing....
-#            if mov.status == visual.PLAYING:
+#            if mov.status == constants.PLAYING:
 #                mov.pause()
-#            elif mov.status == visual.PAUSED:
+#            elif mov.status == constants.PAUSED:
 #                # To /unpause/ the movie if pause has been called....
 #                display_frame_num = mov.play()
 #        elif key == 'period':
