@@ -78,23 +78,7 @@ class TestExpt():
     def teardown_class(cls):
         shutil.rmtree(cls.tmp_dir, ignore_errors=True)
 
-    def test_xsd(self):
-        # get files
 
-        psyexp_files = []
-
-        for root, dirs, files in os.walk(os.path.join(self.exp.prefsPaths['demos'], 'builder')):
-            for f in files:
-                if f.endswith('.psyexp'):
-                    psyexp_files.append(os.path.join(root, f))
-
-        # get schema
-
-        schema_name = path.join(self.exp.prefsPaths['psychopy'], 'experiment', 'experiment.xsd')
-        schema = xmlschema.XMLSchema(schema_name)
-
-        for psyexp_file in psyexp_files:
-            assert schema.is_valid(psyexp_file), f"Error in {psyexp_file}:\n" + "\n".join(err.reason for err in schema.iter_errors(psyexp_file))
 
     def _checkLoadSave(self, file):
         exp = self.exp
@@ -117,15 +101,7 @@ class TestExpt():
 
         return py_file, psyexp_file
 
-    def _checkCompile(self, py_file):
-        # compile the temp file to .pyc, catching error msgs
-        # (including no file at all):
-        try:
-            py_compile.compile(py_file, doraise=True)
-        except py_compile.PyCompileError as err:
-            err.msg = py_file
-            raise err
-        return py_file + 'c'
+
 
     def _checkPyDiff(self, file_py, file2_py):
         """return '' for no meaningful diff, or a diff patch"""
@@ -240,55 +216,6 @@ class TestExpt():
         #assert not diff_in_file_psyexp # was failing most times, uninformative
         #assert not diff_in_file_pyc    # oops, was failing every time despite identical .py file
 
-    def test_future(self):
-        """An experiment file with made-up params and routines to see whether
-        future versions of experiments will get loaded.
-        """
-        expfile = path.join(self.exp.prefsPaths['tests'], 'data', 'futureParams.psyexp')
-        self.exp.loadFromXML(expfile) # reload the edited file
-        # we don't test this script but make sure it builds
-        script = self.exp.writeScript(expPath=expfile)
-        py_file = os.path.join(self.tmp_dir, 'testFutureFile.py')
-        # save the script:
-        with codecs.open(py_file, 'w', 'utf-8-sig') as f:
-            f.write(script)
-
-        #check that files compiles too
-        self._checkCompile(py_file)
-
-    def test_loopBlocks(self):
-        """An experiment file with made-up params and routines to see whether
-        future versions of experiments will get loaded.
-        """
-        #load the test experiment (with a stims loop, trials loop and blocks loop)
-        expfile = path.join(self.exp.prefsPaths['tests'], 'data', 'testLoopsBlocks.psyexp')
-        self.exp.loadFromXML(expfile) # reload the edited file
-        #alter the settings so the data goes to our tmp dir
-        datafileBase = os.path.join(self.tmp_dir, 'testLoopsBlocks')
-        datafileBaseRel = os.path.relpath(datafileBase,expfile)
-        self.exp.settings.params['Data filename'].val = repr(datafileBaseRel)
-        #write the script from the experiment
-        script = self.exp.writeScript(expPath=expfile)
-        py_file = os.path.join(self.tmp_dir, 'testLoopBlocks.py')
-
-        # save it
-        with codecs.open(py_file, 'w', 'utf-8-sig') as f:
-            f.write(script)
-
-        stdout, stderr = core.shellCall([sys.executable, py_file], stderr=True)
-        if stderr:
-            with codecs.open(expfile + "_local.py", "w", 'utf-8-sig') as f:
-                f.write(script)
-            raise AssertionError(f"File {py_file} raised error:\n {stderr}")
-
-        #load the data
-        print("searching..." +datafileBase)
-        print(glob.glob(datafileBase+'*'))
-        f = open(datafileBase+".csv", 'rb')
-        dat = numpy.recfromcsv(f, case_sensitive=True)
-        f.close()
-        assert len(dat)==8 # because 4 'blocks' with 2 trials each (3 stims per trial)
-
     def test_Run_FastStroopPsyExp(self):
         # start from a psyexp file, loadXML, execute, get keypresses from a emulator thread
         if sys.platform.startswith('linux'):
