@@ -5,14 +5,11 @@
 """
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2022 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
 # Author: Jeremy Gray, Oct 2012; localization 2014
 
-from __future__ import absolute_import, division, print_function
-
-from builtins import map, str, range, object
 from pyglet.gl import gl_info
 import os
 import sys
@@ -28,7 +25,7 @@ else:
     tmpApp = wx.App(False)
 from psychopy.localization import _translate
 from psychopy import (info, data, visual, gui, core, __version__,
-                      prefs, event, constants)
+                      prefs, event)
 
 # set values, using a form that poedit can discover:
 _localized = {
@@ -65,7 +62,7 @@ _localized = {
 # can't just do the following, or messes up poedit autodiscovery:
 # _localized = {k: _translate(k) for k in _loKeys}
 
-class BaseWizard(object):
+class BaseWizard():
     """Base class of ConfigWizard and BenchmarkWizard.
     """
     def __init__(self):
@@ -119,7 +116,7 @@ class BaseWizard(object):
                        _translate('avoid upgrading during an experiment'),
                        False))
         msg = _translate(
-            'can be set in <a href="http://www.psychopy.org/general/'
+            'can be set in <a href="https://www.psychopy.org/general/'
             'prefs.html#application-settings-app">Preferences -> App</a>')
         report.append(('locale', items['systemLocale'], msg, False))
         msg = ''
@@ -160,7 +157,7 @@ class BaseWizard(object):
         msg = ''
         if items['openGLVersion'] < '2.':
             msg = _translate(
-                'Warning: <a href="http://www.psychopy.org/general/timing'
+                'Warning: <a href="https://www.psychopy.org/general/timing'
                 '/reducingFrameDrops.html?highlight=OpenGL+2.0">OpenGL '
                 '2.0 or higher is ideal</a>.')
             warn = True
@@ -175,7 +172,7 @@ class BaseWizard(object):
         msg = ''
         if not items['windowHaveShaders']:
             msg = _translate(
-                'Warning: <a href="http://www.psychopy.org/general/timing'
+                'Warning: <a href="https://www.psychopy.org/general/timing'
                 '/reducingFrameDrops.html?highlight=shader">Rendering of'
                 ' complex stimuli will be slow</a>.')
             warn = True
@@ -184,7 +181,7 @@ class BaseWizard(object):
 
         warn = False
         msg = _translate(
-            'during the drifting <a href="http://www.psychopy.org/api/'
+            'during the drifting <a href="https://www.psychopy.org/api/'
             'visual/gratingstim.html">GratingStim</a>')
         if items['windowRefreshTimeMedian_ms'] < 3.3333333:
             msg = _translate(
@@ -216,7 +213,7 @@ class BaseWizard(object):
             dots100.draw()
             win.flip()
         msg = _translate(
-            'during <a href="http://www.psychopy.org/api/visual/'
+            'during <a href="https://www.psychopy.org/api/visual/'
             'dotstim.html">DotStim</a> with 100 random dots')
         warn = False
         intervalsMS = np.array(win.frameIntervals) * 1000
@@ -224,7 +221,7 @@ class BaseWizard(object):
         nDropped = sum(intervalsMS > (1.5 * median))
         if nDropped:
             msg = _translate(
-                'Warning: could not keep up during <a href="http://'
+                'Warning: could not keep up during <a href="https://'
                 'www.psychopy.org/api/visual/dotstim.html">DotStim</a>'
                 ' with 100 random dots.')
             warn = True
@@ -288,7 +285,7 @@ class BaseWizard(object):
         report.append(('auto proxy',
                        str(self.prefs.connections['autoProxy']),
                        _translate('try to auto-detect a proxy if needed; see'
-                                  ' <a href="http://www.psychopy.org/general'
+                                  ' <a href="https://www.psychopy.org/general'
                                   '/prefs.html#connection-settings-connection'
                                   's">Preferences -> Connections</a>'),
                        False))
@@ -298,7 +295,7 @@ class BaseWizard(object):
             prx = str(self.prefs.connections['proxy'])
         report.append(('proxy setting', prx,
                        _translate('current manual proxy setting from <a '
-                                  'href="http://www.psychopy.org/general/'
+                                  'href="https://www.psychopy.org/general/'
                                   'prefs.html#connection-settings-connections'
                                   '">Preferences -> Connections</a>'), False))
 
@@ -313,24 +310,19 @@ class BaseWizard(object):
         # ----- IMPORTS (relevant for developers & non-StandAlone): -----
         if verbose:  # always False for a real first-run
             report.append((_translate('Python packages'), '', '', False))
-            packages = ['PIL', 'openpyxl', 'lxml', 'setuptools', 'pytest',
+            packages = ['PIL', 'openpyxl', 'setuptools', 'pytest',
                         'sphinx', 'psignifit', 'pyserial', 'pp',
                         'pynetstation', 'labjack']
             if sys.platform == 'win32':
                 packages.append('pywin32')
                 packages.append('winioport')
 
-            if constants.PY3:
-                pkgError = ModuleNotFoundError
-            else:
-                pkgError = ImportError
+            pkgError = ModuleNotFoundError
             for pkg in packages:
                 try:
                     if pkg == 'PIL':
                         import PIL
                         ver = PIL.__version__
-                    # elif pkg == 'lxml':
-                    #
                     elif pkg == 'pynetstation':
                         from psychopy.hardware import egi
                         ver = 'import ok'
@@ -392,10 +384,10 @@ class BaseWizard(object):
                                'psychopySplash.png')
         _head = (u'<html><head><meta http-equiv="Content-Type" '
                  'content="text/html; charset=utf-8"></head><body>' +
-                 '<a href="http://www.psychopy.org"><img src="%s" '
+                 '<a href="https://www.psychopy.org"><img src="%s" '
                  'width=396 height=156></a>')
         self.header = _head % imgfile
-        # self.iconhtml = '<a href="http://www.psychopy.org"><img src="%s"
+        # self.iconhtml = '<a href="https://www.psychopy.org"><img src="%s"
         #   width=48 height=48></a>' % self.iconfile
         _foot = _translate('This page was auto-generated by the '
                            'PsychoPy configuration wizard on %s')
@@ -454,9 +446,9 @@ class BaseWizard(object):
                 '''<button onClick="toggle('ok', '');">''' + \
                 _translate('Show all information') + '</button></p>'
             htmlDoc += _translate('''<p>Resources:
-                | <a href="http://www.psychopy.org/documentation.html">On-line documentation</a>
-                | Download <a href="http://www.psychopy.org/PsychoPyManual.pdf">PDF manual</a>
-                | <a href="https://discourse.osychopy.org">Search the user-group archives</a>
+                | <a href="https://www.psychopy.org/documentation.html">On-line documentation</a>
+                | Download <a href="https://www.psychopy.org/PsychoPyManual.pdf">PDF manual</a>
+                | <a href="https://discourse.psychopy.org">Search the user-group archives</a>
                 </p>''')
             htmlDoc += '<hr><p></p>    <table cellspacing=8 border=0>\n'
             htmlDoc += '    <tr><td><font size=+1><strong>' + \
@@ -543,17 +535,17 @@ class ConfigWizard(BaseWizard):
                 <li> On Windows, don't use the windows option to check for updates
                   - it can report that there are no updates available.
                 <li> If your card is made by NVIDIA, go to
-                  <a href="http://www.nvidia.com/Drivers">the NVIDIA website</a>
+                  <a href="https://www.nvidia.com/download/index.aspx">the NVIDIA website</a>
                   and use the 'auto detect' option. Try here for
-                  <a href="http://support.amd.com/">ATI / Radeon drivers</a>. Or try
-                  <a href="http://www.google.com/search?q=download+drivers+%(card2)s">
+                  <a href="https://www.amd.com/fr/support">ATI / Radeon drivers</a>. Or try
+                  <a href="https://www.google.com/search?q=download+drivers+%(card2)s">
                   this google search</a> [google.com].
                 <li> Download and install the driver.
                 <li> Reboot the computer.
                 <li> Restart PsychoPy.</p>
                 <p>If you updated the drivers and still get this message, you'll
                   need a different video card to use PsychoPy. Click
-                <a href="http://www.psychopy.org/installation.html#recommended-hardware">here
+                <a href="https://www.psychopy.org/installation.html#recommended-hardware">here
                 for more information</a> [psychopy.org].</p>
             """)
             fatalItemsList.append(msg % {'card': cardInfo,
