@@ -4,18 +4,20 @@
 """Display an image on `psycopy.visual.Window`"""
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2022 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
-from __future__ import absolute_import, division, print_function
 
-from builtins import str
+
 
 # Ensure setting pyglet.options['debug_gl'] to False is done prior to any
 # other calls to pyglet or pyglet submodules, otherwise it may not get picked
 # up by the pyglet GL engine and have no effect.
 # Shaders will work but require OpenGL2.0 drivers AND PyOpenGL3.0+
 import pyglet
+
+from psychopy.layout import Size
+
 pyglet.options['debug_gl'] = False
 import ctypes
 GL = pyglet.gl
@@ -23,7 +25,7 @@ GL = pyglet.gl
 import numpy
 
 import psychopy  # so we can get the __path__
-from psychopy import logging
+from psychopy import logging, colors
 
 from psychopy.tools.attributetools import attributeSetter, setAttribute
 from psychopy.tools.arraytools import val2array
@@ -43,11 +45,12 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
                  units="",
                  pos=(0.0, 0.0),
                  size=None,
+                 anchor="center",
                  ori=0.0,
                  color=(1.0, 1.0, 1.0),
                  colorSpace='rgb',
                  contrast=1.0,
-                 opacity=1.0,
+                 opacity=None,
                  depth=0,
                  interpolate=False,
                  flipHoriz=False,
@@ -81,22 +84,23 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
         self._imName = image
         self.isLumImage = None
         self.interpolate = interpolate
+        self.vertices = None
+        self.anchor = anchor
         self.flipHoriz = flipHoriz
         self.flipVert = flipVert
         self._requestedSize = size
         self._origSize = None  # updated if an image texture gets loaded
-        self.size = val2array(size)
+        self.size = size
         self.pos = numpy.array(pos, float)
         self.ori = float(ori)
         self.depth = depth
 
         # color and contrast etc
+        self.rgbPedestal = [0, 0, 0] # does an rgb pedestal make sense for an image?
+        self.colorSpace = colorSpace  # omit decorator
+        self.color = color
         self.contrast = float(contrast)
-        self.opacity = float(opacity)
-        self.__dict__['colorSpace'] = colorSpace  # omit decorator
-        self.setColor(color, colorSpace=colorSpace, log=False)
-        # does an rgb pedestal make sense for an image?
-        self.rgbPedestal = [0, 0, 0]
+        self.opacity = opacity
 
         # Set the image and mask-
         self.setImage(image, log=False)
@@ -185,52 +189,6 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
 
         GL.glEndList()
 
-    # for the sake of older graphics cards------------------------------------
-    def _updateListNoShaders(self):
-        """The user shouldn't need this method since it gets called
-        after every call to .set() Basically it updates the OpenGL
-        representation of your stimulus if some parameter of the
-        stimulus changes. Call it if you change a property manually
-        rather than using the .set() command.
-        """
-        self._needUpdate = False
-        GL.glNewList(self._listID, GL.GL_COMPILE)
-        # glColor can interfere with multitextures
-        GL.glColor4f(1.0, 1.0, 1.0, 1.0)
-        # mask
-        GL.glActiveTexture(GL.GL_TEXTURE1)
-        GL.glEnable(GL.GL_TEXTURE_2D)  # implicitly disables 1D
-        GL.glBindTexture(GL.GL_TEXTURE_2D, self._maskID)
-
-        # main texture
-        GL.glActiveTexture(GL.GL_TEXTURE0)
-        GL.glEnable(GL.GL_TEXTURE_2D)
-        GL.glBindTexture(GL.GL_TEXTURE_2D, self._texID)
-
-        # access just once because it's slower than basic property
-        vertsPix = self.verticesPix
-        GL.glBegin(GL.GL_QUADS)  # draw a 4 sided polygon
-        # right bottom
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE0_ARB, 1, 0)
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE1_ARB, 1, 0)
-        GL.glVertex2f(vertsPix[0, 0], vertsPix[0, 1])
-        # left bottom
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE0_ARB, 0, 0)
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE1_ARB, 0, 0)
-        GL.glVertex2f(vertsPix[1, 0], vertsPix[1, 1])
-        # left top
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE0_ARB, 0, 1)
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE1_ARB, 0, 1)
-        GL.glVertex2f(vertsPix[2, 0], vertsPix[2, 1])
-        # right top
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE0_ARB, 1, 1)
-        GL.glMultiTexCoord2fARB(GL.GL_TEXTURE1_ARB, 1, 1)
-        GL.glVertex2f(vertsPix[3, 0], vertsPix[3, 1])
-        GL.glEnd()
-
-        GL.glDisable(GL.GL_TEXTURE_2D)
-        GL.glEndList()
-
     def __del__(self):
         """Remove textures from graphics card to prevent crash
         """
@@ -238,7 +196,7 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
             if hasattr(self, '_listID'):
                 GL.glDeleteLists(self._listID, 1)
             self.clearTextures()
-        except ModuleNotFoundError:
+        except (ImportError, ModuleNotFoundError, TypeError):
             pass  # has probably been garbage-collected already
 
     def draw(self, win=None):
@@ -254,11 +212,7 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
 
         GL.glPushMatrix()  # push before the list, pop after
         win.setScale('pix')
-
-        desiredRGB = self._getDesiredRGB(self.rgb, self.colorSpace,
-                                         self.contrast)
-        GL.glColor4f(desiredRGB[0], desiredRGB[1], desiredRGB[2],
-                     self.opacity)
+        GL.glColor4f(*self._foreColor.render('rgba1'))
 
         if self._needTextureUpdate:
             self.setImage(value=self._imName, log=False)
@@ -269,11 +223,57 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
         # return the view to previous state
         GL.glPopMatrix()
 
+    # overload ColorMixin methods so that they refresh the image after being called
+    @property
+    def foreColor(self):
+        # Call setter of parent mixin
+        return ColorMixin.foreColor.fget(self)
+    @foreColor.setter
+    def foreColor(self, value):
+        # Call setter of parent mixin
+        ColorMixin.foreColor.fset(self, value)
+        # Reset the image and mask-
+        self.setImage(self._imName, log=False)
+        self.texRes = self.__dict__['texRes']  # rebuilds the mask
+    @property
+    def contrast(self):
+        # Call setter of parent mixin
+        return ColorMixin.contrast.fget(self)
+    @contrast.setter
+    def contrast(self, value):
+        # Call setter of parent mixin
+        ColorMixin.contrast.fset(self, value)
+        # Reset the image and mask-
+        self.setImage(self._imName, log=False)
+        self.texRes = self.__dict__['texRes']  # rebuilds the mask
+    @property
+    def opacity(self):
+        # Call setter of parent mixin
+        return BaseVisualStim.opacity.fget(self)
+    @opacity.setter
+    def opacity(self, value):
+        # Call setter of parent mixin
+        BaseVisualStim.opacity.fset(self, value)
+        # Reset the image and mask-
+        self.setImage(self._imName, log=False)
+        self.texRes = self.__dict__['texRes']  # rebuilds the mask
+
     @attributeSetter
     def image(self, value):
         """The image file to be presented (most formats supported).
+	   
+	This can be a path-like object to an image file, or a numpy
+	array of shape [H, W, C] where C are channels. The third dim
+	will usually have length 1 (defining an intensity-only image), 3
+	(defining an RGB image) or 4 (defining an RGBA image).
+	
+	If passing a numpy array to the image attribute,
+	the size attribute of ImageStim must be set explicitly.
         """
         self.__dict__['image'] = self._imName = value
+        # If given a color array, get it in rgb1
+        if isinstance(value, colors.Color):
+            value = value.render('rgb1')
 
         wasLumImage = self.isLumImage
         if type(value) != numpy.ndarray and value == "color":
@@ -292,7 +292,7 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
                                                   wrapping=False)
         # if user requested size=None then update the size for new stim here
         if hasattr(self, '_requestedSize') and self._requestedSize is None:
-            self.size = None  # set size to default
+            self.size = Size(numpy.array(self._origSize), units='pix', win=self.win)  # set size to default
         # if we switched to/from lum image then need to update shader rule
         if wasLumImage != self.isLumImage:
             self._needUpdate = True
@@ -320,6 +320,7 @@ class ImageStim(BaseVisualStim, ContainerMixin, ColorMixin, TextureMixin):
                             stim=self,
                             res=self.texRes,
                             maskParams=self.maskParams,
+                            forcePOW2=False,
                             wrapping=True)
 
     def setMask(self, value, log=None):
